<?php
namespace Modules\Cotacao\Modules\Pedido\Services;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource;
use Teknisa\Model\Suprimentos\Entities\Prmarcpedcol;
use Teknisa\Model\Suprimentos\Entities\Itempedcol;
use Teknisa\Model\Suprimentos\Entities\Pedcolgeral;
use Teknisa\Model\Geral\Entities\Lista;
use Util\SupUtilities;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class ControlePedidoColetaService {

    protected $entityManager;
    protected $environment;
    protected $dataSourceManager;
    protected $newCode;
    protected $smtpUtil;
    protected $supUtilities;
    protected $fileServerURL;
    protected $controlePedidoColetaAceiteService;

    public function __construct(EntityManager $entityManager, $environment, DataSource\Manager $dataSourceManager, $newCode, $smtpUtil, SupUtilities $supUtilities, $fileServerURL, $controlePedidoColetaAceiteService)
    {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
        $this->smtpUtil = $smtpUtil;
        $this->supUtilities = $supUtilities;
        $this->fileServerURL = $fileServerURL;
        $this->controlePedidoColetaAceiteService = $controlePedidoColetaAceiteService;
    }

    public function iniciaTransacao(){
        $this->entityManager->beginTransaction();
    }

    public function commit(){
        $this->entityManager->commit();
    }

    public function flush(){
        $this->entityManager->flush();
    }

    public function rollback(){
        $this->entityManager->rollback();
    }
    
    public function getCdFilial()
    {
        return $this->environment->getCdFilial();
    }

    public function atualizaPrecObj($produto)
    {
        try {
            $prmarcpedcol = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Prmarcpedcol')
                ->findOneBy(
                    array(
                        "nrorg"       => $produto['NRORG'],
                        "cdfilial"    => $produto['CDFILIAL'],
                        "nrpedidocol" => $produto['NRPEDIDOCOL'],
                        "cdproduto"   => $produto['CDPRODUTO'],
                        "cdmarca"     => $produto['CDMARCA']
                    )
                );
                
            if ($prmarcpedcol instanceof Prmarcpedcol) {
                $prmarcpedcol->setDsobsrenegocia($produto['DSOBSRENEGOCIA']);
                $prmarcpedcol->setVrprecoobjetivo($produto['VRPRECOOBJETIVO']);
                $prmarcpedcol->setNrorgultatu($produto['NRORG']);
                $prmarcpedcol->setIditpedprioneg($produto['IDITPEDPRIONEG']);
                $prmarcpedcol->setDtultatu(new \DateTime());
                $prmarcpedcol->setCdoperultatu($this->environment->getCdoperador());
                
                $this->entityManager->persist($prmarcpedcol);
            }
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function atualizaPrecObjItmPedCol($produto)
    {
        try {
            $pedcoleta = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Pedcoleta')
                ->findBy(
                    array(
                        "nrorg"           => $produto['NRORG'],
                        "cdfilial"        => $produto['CDFILIAL'],
                        "nrpedidocol"     => $produto['NRPEDIDOCOL'],
                        "cdforneced"      => $produto['CDFORNECED']
                    )
                );
            
            foreach ($pedcoleta as $item) {
                $itempedcol = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Itempedcol')
                    ->findOneBy(
                        array(
                            "nrorg"           => $produto['NRORG'],
                            "cdfilial"        => $produto['CDFILIAL'],
                            "nrpedcoleta"     => $item->getNrpedcoleta(),
                            "cdproduto"       => $produto['CDPRODUTO'],
                            "cdmarca"         => $produto['CDMARCA'],
                            "cdforneced"      => $produto['CDFORNECED'],
                            "cdregiao"        => $item->getCdregiao()
                        )
                    );
                    
                if ($itempedcol instanceof Itempedcol) {
                    $itempedcol->setVrprecoobjetivo($produto['VRPRECOOBJETIVO']);
                    $itempedcol->setDsobsrenegocia($produto['DSOBSRENEGOCIA']);
                    $itempedcol->setIditpedprioneg($produto['IDITPEDPRIONEG']);
                    $itempedcol->setNrorgultatu($produto['NRORG']);
                    $itempedcol->setDtultatu(new \DateTime());
                    $itempedcol->setCdoperultatu($this->environment->getCdoperador());
                    
                    $this->entityManager->persist($itempedcol);
                }
            }
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function preencheGrafico($produto)
    {
        try {
            $connection = $this->entityManager->getConnection();
            $sql = "INSERT INTO HISTNEGOCIAPCOL(
                        NRHISTNEGOCIAPCOL,
                        CDFILIAL, NRPEDIDOCOL, DTINIVALPCOL, DTFINVALPCOL, CDCOMPRADOR, 
                        DSOBSRENEGOCIA, CDPRODUTO, CDMARCA, VRUNITATUAL, VRPRECRENEG, 
                        VROBJATUAL, IDITPEDPRIONEG, DTOPERHISTPCOL, CDOPERRESP, DTINCLUSAO, NRORG) 
                    VALUES ( 
                        SEQ_HISTNEGOCIAPCOL.NEXTVAL, 
                        :CDFILIAL, :NRPEDIDOCOL, :DTINIVALPCOL, :DTFINVALPCOL, :CDCOMPRADOR, 
                        :DSOBSRENEGOCIA, :CDPRODUTO, :CDMARCA, :VRUNITATUAL, :VRPRECRENEG, 
                        :VROBJATUAL, :IDITPEDPRIONEG, TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS'), :CDOPERRESP, TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS'), :NRORG)";
                
            $query = $this->entityManager->getConnection()->prepare($sql);
            
            $query->bindValue("CDFILIAL",       $produto['CDFILIAL']);
            $query->bindValue("NRPEDIDOCOL",    $produto['NRPEDIDOCOL']);
            $query->bindValue("DTINIVALPCOL",   $produto['DTINIPERCOT']);
            $query->bindValue("DTFINVALPCOL",   $produto['DTFINPERCOT']);
            $query->bindValue("CDCOMPRADOR",    $produto['COMPRADOR']);
            $query->bindValue("DSOBSRENEGOCIA", $produto['DSOBSRENEGOCIA']);
            $query->bindValue("CDPRODUTO",      $produto['CDPRODUTO']);
            $query->bindValue("CDMARCA",        $produto['CDMARCA']);
            $query->bindValue("VRUNITATUAL",    $produto['VRPRECUNIT']);
            $query->bindValue("VRPRECRENEG",    $produto['VRPRECREN']);
            $query->bindValue("VROBJATUAL",     $produto['VRPRECOOBJETIVO']);
            $query->bindValue("IDITPEDPRIONEG", $produto['IDITPEDPRIONEG']);
            $query->bindValue("CDOPERRESP",     $this->environment->getCdOperador());
            $query->bindValue("NRORG",          $this->environment->getNrOrgTrab());
            $query->execute();
        } catch (\Exception $e) {
		    throw $e;
		}
    }

    public function atualizaSituPedcolgeral($pedido, $dtExpirapedcol)
    {
        try {
            $pedcolgeral = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Pedcolgeral')
                ->findOneBy(
                    array(
                        "nrorg"       => $this->environment->getNrOrgTrab(),
                        "cdfilial"    => $pedido['CDFILIAL'],
                        "nrpedidocol" => $pedido['NRPEDGRID']
                    )
                );
                
            if ($pedcolgeral instanceof Pedcolgeral) {
                $pedcolgeral->setIdrenegociapcol($pedido['IDRENEGOCIAPCOL']);
                $pedcolgeral->setIdsitupedcoleta($pedido['IDSITUCOLETAGERAL']);
                $pedcolgeral->setDtexpirapedcol(new \DateTime(str_replace('/', '-', $dtExpirapedcol)));
                $pedcolgeral->setNrorgultatu($this->environment->getNrOrgTrab());
                $pedcolgeral->setDtultatu(new \DateTime());
                $pedcolgeral->setCdoperultatu($this->environment->getCdoperador());
    
                $this->entityManager->persist($pedcolgeral);
            }
        } catch (\Exception $e) {
		    throw $e;
		}
    } 

    public function atualizaSituPedcoleta($pedido)
    {
        try {
            $listaPedcoleta = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Pedcoleta')
                ->findBy(
                    array(
                        "nrorg"       => $this->environment->getNrOrgTrab(),
                        "cdfilial"    => $pedido['CDFILIAL'],
                        "nrpedidocol" => $pedido['NRPEDGRID']
                    )
                );
    
            foreach ($listaPedcoleta as $pedcoleta) {
                if ($pedcoleta instanceof Pedcoleta) {
                    $pedcoleta->setIdsitupedcol($pedido['IDSITUPEDCOL']);
                    $pedcoleta->setNrorgultatu($this->environment->getNrOrgTrab());
                    $pedcoleta->setDtultatu(new \DateTime());
                    $pedcoleta->setCdoperultatu($this->environment->getCdoperador());
                    
                    $this->entityManager->persist($pedcoleta);
                }
            }
        } catch (\Exception $e) {
		    throw $e;
		}
    }  

    public function geraCotacao($pedido, $row)
    {
        try {
            $connection = $this->entityManager->getConnection();
            
            $procedure = new StoredProcedure($connection, 'SUP_COTACAO.GRAVA_COTWEB');
            $procedure->addParam(new Param('P_CDFILIAL',    Param::PARAM_INPUT,  $pedido['CDFILIAL'],    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDCOLETA', Param::PARAM_INPUT,  $pedido['NRPEDCOLETA'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDREGIAO',    Param::PARAM_INPUT,  $pedido['CDREGIAO'],    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFORNECED',  Param::PARAM_INPUT,  $pedido['CDFORNECED'],  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRSEMINI',    Param::PARAM_INPUT,  $pedido['NRSEMINI'],    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRSEMFIN',    Param::PARAM_INPUT,  $pedido['NRSEMFIN'],    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_ENTRALISTA',  Param::PARAM_INPUT,  $row['LISTAPREC'],      Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_COTA_N_GER',  Param::PARAM_OUTPUT, NULL,                   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDOPERINCL',  Param::PARAM_INPUT,  $this->environment->getCdoperador(), Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_TRANSACAO',   Param::PARAM_INPUT,  'N',                    Param::PARAM_TYPE_STR));
            return $procedure->execute();
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function retornaMenorMaiorProdutoPedido($pedidos) {
		$sql = "SELECT DISTINCT PROD.CDARVPROD, PROD.NMPRODUTO
		          FROM PRMARCPEDCOL PR, PRODUTO PROD
		         WHERE (INSTR(:FILIALNRPEDIDOCOL, CONCAT(PR.CDFILIAL, PR.NRPEDIDOCOL)) <> 0)
		           AND PR.NRORG = :NRORG
                   AND PR.CDPRODUTO = PROD.CDPRODUTO
		         ORDER BY CDARVPROD";
        
        $params = array(
            "FILIALNRPEDIDOCOL" => $pedidos['FILIALNRPEDIDOCOL'],
            "NRORG"             => $this->environment->getNrOrgTrab()
        );
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
    
    public function retornaProdutosValorMinimo($consideraMarca, $nrlista, $paramCompPreco) 
    {
        try {
            if($consideraMarca === 'S') {
                if($paramCompPreco === 'E'){
                    $sql = "SELECT PRMARCPEDCOL.CDPRODUTO,
                                   PRODUTO.VRFATOCONV,
                                   MIN(CASE NVL(PRMARCPEDCOL.VRPRECREN, 0) WHEN 0 THEN PRMARCPEDCOL.VRPRECUNIPRMARC ELSE PRMARCPEDCOL.VRPRECREN END / PRODUTO.VRFATOCONV) VRPRECUNIPRMARC,
                                   PRMARCPEDCOL.CDMARCA,
                                   PRODUTO.CDPRODESTO
                              FROM PRMARCPEDCOL INNER JOIN LISTA ON PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                                INNER JOIN PRODUTO ON PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                             WHERE LISTA.NRLISTA = :P_NRLISTA
                               AND PRMARCPEDCOL.VRPRECUNIPRMARC > 0
                             GROUP BY PRMARCPEDCOL.CDPRODUTO,
                                   PRODUTO.VRFATOCONV,
                                   PRMARCPEDCOL.CDMARCA,
                                   PRODUTO.CDPRODESTO";
                    
                } else {
                    $sql = "SELECT PRMARCPEDCOL.CDPRODUTO,
                                   1 VRFATOCONV,
                                   MIN(CASE NVL(PRMARCPEDCOL.VRPRECREN, 0) WHEN 0 THEN PRMARCPEDCOL.VRPRECUNIPRMARC ELSE PRMARCPEDCOL.VRPRECREN END) VRPRECUNIPRMARC,
                                   PRMARCPEDCOL.CDMARCA,
                                   PRODUTO.CDPRODESTO
                              FROM PRMARCPEDCOL INNER JOIN LISTA ON PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                                INNER JOIN PRODUTO ON PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                             WHERE LISTA.NRLISTA = :P_NRLISTA
                               AND PRMARCPEDCOL.VRPRECUNIPRMARC > 0
                             GROUP BY PRMARCPEDCOL.CDPRODUTO,
                                      PRMARCPEDCOL.CDMARCA,
                                      PRODUTO.CDPRODESTO";
                }
            } else {
                if($paramCompPreco === 'E'){
                    $sql = "SELECT PRMARCPEDCOL.CDPRODUTO,
                                   PRODUTO.VRFATOCONV,
                                   MIN(CASE NVL(PRMARCPEDCOL.VRPRECREN, 0) WHEN 0 THEN PRMARCPEDCOL.VRPRECUNIPRMARC ELSE PRMARCPEDCOL.VRPRECREN END / PRODUTO.VRFATOCONV) VRPRECUNIPRMARC,
                                   PRODUTO.CDPRODESTO
                              FROM PRMARCPEDCOL INNER JOIN LISTA ON PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                                INNER JOIN PRODUTO ON PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                             WHERE LISTA.NRLISTA = :P_NRLISTA
                               AND PRMARCPEDCOL.VRPRECUNIPRMARC > 0
                             GROUP BY PRMARCPEDCOL.CDPRODUTO,
                                   PRODUTO.VRFATOCONV,
                                   PRODUTO.CDPRODESTO";
                } else {
                    $sql = "SELECT PRMARCPEDCOL.CDPRODUTO,
                                   1 VRFATOCONV,
                                   MIN(CASE NVL(PRMARCPEDCOL.VRPRECREN, 0) WHEN 0 THEN PRMARCPEDCOL.VRPRECUNIPRMARC ELSE PRMARCPEDCOL.VRPRECREN END) VRPRECUNIPRMARC,
                                   PRODUTO.CDPRODESTO
                              FROM PRMARCPEDCOL INNER JOIN LISTA ON PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                                INNER JOIN PRODUTO ON PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                             WHERE LISTA.NRLISTA = :P_NRLISTA
                               AND PRMARCPEDCOL.VRPRECUNIPRMARC > 0
                             GROUP BY PRMARCPEDCOL.CDPRODUTO,
                                      PRODUTO.CDPRODESTO";
                }
            }
            
            $params = array(
                "P_NRLISTA" => $nrlista
            );
            
    		return $this->supUtilities->crud($sql, $params);
        } catch (\Exception $e) {
		    throw $e;
		}
	}
	
	public function atualizaMelhorPedido($row, $nrlista) 
	{
	    try {
            $sql = "SELECT PRMARCPEDCOL.CDFILIAL, PRMARCPEDCOL.NRPEDIDOCOL, PRMARCPEDCOL.CDPRODUTO
                      FROM PRMARCPEDCOL INNER JOIN LISTA ON PRMARCPEDCOL.CDFILIAL||PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                     WHERE LISTA.NRLISTA = :P_NRLISTA
                       AND PRMARCPEDCOL.CDFILIAL||PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                       AND PRMARCPEDCOL.CDPRODUTO = :P_CDPRODUTO
                       AND CASE NVL(PRMARCPEDCOL.VRPRECREN, 0) WHEN 0 THEN PRMARCPEDCOL.VRPRECUNIPRMARC ELSE PRMARCPEDCOL.VRPRECREN END = :P_VRMIN";
            
            $params = array(
                "P_NRLISTA"   => $nrlista,
                "P_VRMIN"     => $row['VRPRECUNIPRMARC'],
                "P_CDPRODUTO" => $row['CDPRODUTO']
            );

            $pedidos = $this->supUtilities->crud($sql, $params);
            
            if(isset($pedidos) && count($pedidos)) {
                foreach($pedidos as $pedido) {
                    $sql = "UPDATE PRMARCPEDCOL
                               SET IDMELHORPRECO = 'S'
                             WHERE CDFILIAL    = :P_CDFILIAL
                               AND NRPEDIDOCOL = :P_NRPEDIDOCOL
                               AND CDPRODUTO   = :P_CDPRODUTO";
                                
                    $params = array(
                        "P_CDFILIAL"    => $pedido['CDFILIAL'],
                        "P_CDPRODUTO"   => $pedido['CDPRODUTO'],
                        "P_NRPEDIDOCOL" => $pedido['NRPEDIDOCOL']
                    );
                    
                    $this->supUtilities->crud($sql, $params);
                }
            }
	    } catch (\Exception $e) {
		    throw $e;
		}
	}
	
	public function atualizaPrecObjMinPrmarcpedcol($produtoValorMinimo, $nrlista, $paramCompPreco, $precoObjetivoNull = null, $consideraMarca = null)
	{
        try {
            if($precoObjetivoNull) {
    	        if($consideraMarca === 'S') {
        	        $sql = "UPDATE PRMARCPEDCOL
                               SET VRPRECOOBJETIVO = (:VRPRECOOBJETIVO * :VRFATOCONV),
                                   IDITPEDPRIONEG = :P_IDITPEDPRIONEG,
                                   DSOBSRENEGOCIA = :DSOBSRENEGOCIA
                             WHERE CDPRODUTO = :CDPRODUTO
                               AND CDMARCA = :CDMARCA
                               AND EXISTS (SELECT 1
                                             FROM LISTA
                                            WHERE PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                              AND LISTA.NRLISTA = :P_NRLISTA)";
                      
                    $params = array(
                        "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                        "VRFATOCONV"        => $produtoValorMinimo['VRFATOCONV'],
                        "P_IDITPEDPRIONEG"  => $precoObjetivoNull,
                        "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                        "CDMARCA"           => $produtoValorMinimo['CDMARCA'],
                        "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                        "P_NRLISTA"         => $nrlista
                    );
    	        } else {
    	            $sql = "UPDATE PRMARCPEDCOL
                               SET VRPRECOOBJETIVO = (:VRPRECOOBJETIVO * :VRFATOCONV),
                                   IDITPEDPRIONEG = :P_IDITPEDPRIONEG,
                                   DSOBSRENEGOCIA = :DSOBSRENEGOCIA
                             WHERE CDPRODUTO = :CDPRODUTO
                               AND EXISTS (SELECT 1
                                             FROM LISTA
                                            WHERE PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                              AND LISTA.NRLISTA = :P_NRLISTA)";
                      
                    $params = array(
                        "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                        "VRFATOCONV"        => $produtoValorMinimo['VRFATOCONV'],
                        "P_IDITPEDPRIONEG"  => $precoObjetivoNull,
                        "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                        "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                        "P_NRLISTA"         => $nrlista
                    );
    	        }
    	    } else {
    	        if($consideraMarca === 'S') {
                    $sql = "UPDATE PRMARCPEDCOL
                               SET VRPRECOOBJETIVO = (:VRPRECOOBJETIVO * :VRFATOCONV),
                                   IDITPEDPRIONEG = (SELECT CASE
                                                              WHEN NVL(DECODE(PRMARCPEDCOL.VRPRECREN,0, NULL,PRMARCPEDCOL.VRPRECREN), PRMARCPEDCOL.VRPRECUNIPRMARC) > (:VRPRECOOBJETIVO * :VRFATOCONV)
                                                              THEN 'S'
                                                              ELSE 'N'
                                                           END 
                                                      FROM DUAL),
                                   DSOBSRENEGOCIA = :DSOBSRENEGOCIA,
                                   IDMELHORPRECO = NULL
                             WHERE CDPRODUTO = :CDPRODUTO
                               AND CDMARCA = :CDMARCA
                               AND EXISTS (SELECT 1
                                             FROM LISTA
                                            WHERE PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                              AND LISTA.NRLISTA = :P_NRLISTA)";
                              
                    $params = array(
                        "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                        "VRFATOCONV"        => $paramCompPreco === 'E' ? $produtoValorMinimo['VRFATOCONV'] : 1,
                        "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                        "CDMARCA"           => $produtoValorMinimo['CDMARCA'],
                        "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                        "P_NRLISTA"         => $nrlista
                    );
    	        } else {
    	            $sql = "UPDATE PRMARCPEDCOL
                               SET VRPRECOOBJETIVO = (:VRPRECOOBJETIVO * :VRFATOCONV),
                                   IDITPEDPRIONEG = (SELECT CASE
                                                              WHEN NVL(DECODE(PRMARCPEDCOL.VRPRECREN,0, NULL,PRMARCPEDCOL.VRPRECREN), PRMARCPEDCOL.VRPRECUNIPRMARC) > (:VRPRECOOBJETIVO * :VRFATOCONV)
                                                              THEN 'S'
                                                              ELSE 'N'
                                                           END 
                                                      FROM DUAL),
                                   DSOBSRENEGOCIA = :DSOBSRENEGOCIA,
                                   IDMELHORPRECO = NULL
                             WHERE CDPRODUTO = :CDPRODUTO
                               AND EXISTS (SELECT 1
                                             FROM LISTA
                                            WHERE PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                                              AND LISTA.NRLISTA = :P_NRLISTA)";
                              
                    $params = array(
                        "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                        "VRFATOCONV"        => $paramCompPreco === 'E' ? $produtoValorMinimo['VRFATOCONV'] : 1,
                        "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                        "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                        "P_NRLISTA"         => $nrlista
                    );
    	        }
    	    }
        
            $this->supUtilities->crud($sql, $params);
	    } catch (\Exception $e) {
		    throw $e;
		}
	}
	
	public function updateMinItempedcol($item, $nrlista, $paramCompPreco) 
	{
	    try {
	        $vrFatoConv = $paramCompPreco === 'E' ? $item['VRFATOCONV'] : 1;
	        
	        if(isset($item['CDMARCA'])){
	            $sql = "UPDATE ITEMPEDCOL 
                           SET VRPRECOOBJETIVO = :VRPRECOOBJETIVO * :VRFATOCONV,
                               IDITPEDPRIONEG  = (SELECT CASE
                                                          WHEN VRITEMPEDCOL > :VRPRECOOBJETIVO
                                                          THEN 'S'
                                                          ELSE 'N'
                                                         END 
                                                    FROM DUAL),
                               DSOBSRENEGOCIA  = :DSOBSRENEGOCIA
                         WHERE CDPRODUTO = :P_CDPRODUTO
                           AND CDMARCA = :P_CDMARCA
                           AND EXISTS (SELECT 1
                                         FROM PEDCOLETA INNER JOIN LISTA ON PEDCOLETA.CDFILIAL||PEDCOLETA.NRPEDIDOCOL = LISTA.CDLISTA
                                        WHERE LISTA.NRLISTA = :P_NRLISTA
                                          AND ITEMPEDCOL.CDFILIAL = PEDCOLETA.CDFILIAL
                                          AND ITEMPEDCOL.CDREGIAO = PEDCOLETA.CDREGIAO
                                          AND ITEMPEDCOL.NRPEDCOLETA = PEDCOLETA.NRPEDCOLETA
                                          AND ITEMPEDCOL.CDFORNECED = PEDCOLETA.CDFORNECED)";
                $params = array(
                     "VRPRECOOBJETIVO" => $item['VRPRECUNIPRMARC'],
                     "VRFATOCONV"      => $vrFatoConv,
                     "DSOBSRENEGOCIA"  => $item['DSOBSRENEGOCIA'],
                     "P_CDPRODUTO"     => $item['CDPRODUTO'],
                     "P_CDMARCA"       => $item['CDMARCA'],
                     "P_NRLISTA"       => $nrlista
                );
                 
                $this->supUtilities->crud($sql, $params);
	        } else {
	            $sql = "UPDATE ITEMPEDCOL 
                           SET VRPRECOOBJETIVO = :VRPRECOOBJETIVO * :VRFATOCONV,
                               IDITPEDPRIONEG  = (SELECT CASE
                                                          WHEN VRITEMPEDCOL > :VRPRECOOBJETIVO
                                                          THEN 'S'
                                                          ELSE 'N'
                                                         END 
                                                    FROM DUAL),
                               DSOBSRENEGOCIA  = :DSOBSRENEGOCIA
                         WHERE CDPRODUTO = :P_CDPRODUTO
                           AND EXISTS (SELECT 1
                                         FROM PEDCOLETA INNER JOIN LISTA ON PEDCOLETA.CDFILIAL||PEDCOLETA.NRPEDIDOCOL = LISTA.CDLISTA
                                        WHERE LISTA.NRLISTA = :P_NRLISTA
                                          AND ITEMPEDCOL.CDFILIAL = PEDCOLETA.CDFILIAL
                                          AND ITEMPEDCOL.CDREGIAO = PEDCOLETA.CDREGIAO
                                          AND ITEMPEDCOL.NRPEDCOLETA = PEDCOLETA.NRPEDCOLETA
                                          AND ITEMPEDCOL.CDFORNECED = PEDCOLETA.CDFORNECED)";
                $params = array(
                     "VRPRECOOBJETIVO" => $item['VRPRECUNIPRMARC'],
                     "VRFATOCONV"      => $vrFatoConv,
                     "DSOBSRENEGOCIA"  => $item['DSOBSRENEGOCIA'],
                     "P_CDPRODUTO"     => $item['CDPRODUTO'],
                     "P_NRLISTA"       => $nrlista
                );
                 
                $this->supUtilities->crud($sql, $params);
            }
	    } catch (\Exception $e) {
		    throw $e;
		}
	}
	
	public function insereLista($listaCdlista)
    {
        try {
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrgTrab());
            
            $this->iniciaTransacao();
            
            foreach ($listaCdlista as $cdlista) {
                $lista = new Lista();
                
                $lista->setNrlista($nrlista);
                $lista->setCdlista($cdlista);
                $lista->setNrorg($this->environment->getNrOrgTrab());
                $lista->setNrorginclusao($this->environment->getNrOrgTrab());
                
                $lista->setCdoperultatu($this->environment->getCdoperador());
                $lista->setNrorgultatu($this->environment->getNrOrgTrab());
                
                $lista->setCdoperinclusao($this->environment->getCdoperador());
                $lista->setDtinclusao(new \DateTime());
                $lista->setDtultatu(new \DateTime());
                $this->entityManager->persist($lista);
            }
            $this->flush();
            $this->commit();
            
            return $nrlista;
        } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
    }
    
    public function deletaLista($nrlista) 
    {
        try {
            $this->iniciaTransacao();
            
            $listas = $this->entityManager->getRepository('Teknisa\Model\Geral\Entities\Lista')
                ->findBy(
                    array(
                        "nrorg"         => $this->environment->getNrOrgTrab(),
                        "nrlista"       => $nrlista
                    )
                );
            
            foreach($listas as $lista){
                if ($lista instanceof Lista) {
                    $this->entityManager->remove($lista);
                    $this->flush();
                }
            }
            $this->flush();
            $this->commit();
        } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
    }
    
    public function saveComments($data)
    {
        try {
            
            $sql = "INSERT INTO COMENTPEDCOL (CDFILIAL, NRPEDIDOCOL, DTCOMENTARIO, CDOPERADOR, TXCOMENTARIO, DTINCLUSAO, DTULTATU, NRORG) 
                                      VALUES (:P_CDFILIAL, :P_NRPEDIDOCOL, SYSDATE, :P_CDOPERADOR, :P_TXCOMENTARIO, SYSDATE, SYSDATE, :NRORG)";
            
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            
            foreach ($data as $row) {
                if(!$row['NOTEXISTSPED']){
                    $stmt->execute(
                        array(
                            "P_CDFILIAL"     => $row['CDFILIAL'],
                            "P_NRPEDIDOCOL"  => $row['NRPEDIDOCOL'],
                            "P_CDOPERADOR"   => $this->environment->getCdOperador(),
                            "P_TXCOMENTARIO" => $row['COMMENT'],
                            "NRORG"   => $this->environment->getNrOrgTrab()
                        )
                    );
                }
            }
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function salvarComentario ($row, $regiao = false) {
        if($regiao){
            $stringPos   = '<br>';
            $pos      = strpos($row['TXCOMENTARIO'], $stringPos);
            $text = substr_replace($row['TXCOMENTARIO'], ' ' , $pos, strlen($stringPos));
            
            $stringReplace = array("<br>");
            $string   = array(", ");
            
            $row['TXCOMENTARIO'] = str_replace($stringReplace, $string, $text);
                                
        }
        
        if (isset($row["fileUpload"]) && isset($row["fileUpload"][0]) && isset($row["fileUpload"][0]["name"]) && isset($row["fileUpload"][0]["path"])){
            $dsDocumento = $row["fileUpload"][0]["name"];
            $documento = $row["fileUpload"][0]["path"];
        } else {
            $dsDocumento = ' ';
            $documento = ' ';
        }
        
        $cdFilial = isset($row['CDFILIAL']) ? $row['CDFILIAL'] : $row['pedidosSelecionados'][0]['CDFILIAL'];
        $nrPedidoCol = isset($row['NRPEDIDOCOL']) ? $row['NRPEDIDOCOL'] : $row['pedidosSelecionados'][0]['NRPEDIDOCOL'];
        $sql = "INSERT INTO COMENTPEDCOL ( CDFILIAL, NRPEDIDOCOL, DTCOMENTARIO, CDOPERADOR, TXCOMENTARIO, DTINCLUSAO, DTULTATU, NRORG, DSDOCUMENTOANEXO, DSIDDOCFILESERV ) VALUES ( :P_CDFILIAL, :P_NRPEDIDOCOL, SYSDATE, :P_CDOPERADOR, :P_TXCOMENTARIO, SYSDATE, SYSDATE, :NRORG, :DSDOCUMENTOANEXO, :DSIDDOCFILESERV )";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $cdFilial,
                "P_NRPEDIDOCOL"  => $nrPedidoCol,
                "P_CDOPERADOR"   => $this->environment->getCdOperador(),
                "P_TXCOMENTARIO" => $row['TXCOMENTARIO'],
                "NRORG"   => $this->environment->getNrOrgTrab(),
                "DSDOCUMENTOANEXO" => $dsDocumento,
                "DSIDDOCFILESERV" => $documento
            )
        );

    }
    
    public function infoComentario($row) {
        $cdFilial = isset($row['CDFILIAL']) ? $row['CDFILIAL'] : $row['pedidosSelecionados'][0]['CDFILIAL'];
        $nrPedidoCol = isset($row['NRPEDIDOCOL']) ? $row['NRPEDIDOCOL'] : $row['pedidosSelecionados'][0]['NRPEDIDOCOL'];
        $sql = "SELECT C.CDFILIAL, C.NRPEDIDOCOL, C.CDOPERADOR, O.NMOPERADOR, O.DSEMAILOPER, C.DTCOMENTARIO, C.TXCOMENTARIO FROM (SELECT * FROM COMENTPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDOPERADOR = :P_CDOPERADOR ORDER BY DTCOMENTARIO DESC) C, OPERADOR O WHERE C.CDOPERADOR = O.CDOPERADOR AND ROWNUM = 1";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $cdFilial,
                "P_NRPEDIDOCOL"  => $nrPedidoCol,
                "P_CDOPERADOR"   => $this->environment->getCdOperador()
            )
        );
        return($stmt->fetchAll()[0]);
    }
    
    public function infoOperador($row) {
        $comprador = isset($row['COMPRADOR']) ? $row['COMPRADOR'] : $row['pedidosSelecionados'][0]['COMPRADOR'];
        $sql = "SELECT CDOPERADOR, DSEMAILOPER, NMOPERADOR FROM OPERADOR WHERE CDOPERADOR = :CDOPERADOR";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array("CDOPERADOR" => $comprador)
        );
        return($stmt->fetchAll()[0]);
    }
    
    public function getMessage($infoComentario) {
        $operador     = $infoComentario["NMOPERADOR"] ? $infoComentario["NMOPERADOR"] : $infoComentario["DSEMAILOPER"];
        $comentario   = nl2br($infoComentario["TXCOMENTARIO"]);
        $numeroPedido = $infoComentario["NRPEDIDOCOL"];
        $time         = explode(" ", $infoComentario["DTCOMENTARIO"]);
        $data         = $time[0];
        $hora         = $time[1];
        
        $message      = "<table>
                            <tr>
                                <td>"
                                    . $operador ." incluiu um novo comentário no pedido <b>" . $numeroPedido . "</b> em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora ."</b>. 
                                </td>
                            </tr>
                            <tr>
                                <td class='title'> 
                                    <div>
                                        <br/> Comentário
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>
                                    <br/>" . $comentario .
                                "</td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> Email automático enviado pelo Suprimentos. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
        return $message;
    }
    
    public function getMessageInconsistencia($infoComentario) {
        $operador     = $infoComentario["NMOPERADOR"] ? $infoComentario["NMOPERADOR"] : $infoComentario["DSEMAILOPER"];
        $numeroPedido = $infoComentario["NRPEDIDOCOL"];
        $time         = explode(" ", $infoComentario["DTCOMENTARIO"]);
        $data         = $time[0];
        $hora         = $time[1];
        
        $message      = "<table>
                            <tr>
                                <td class='title'> 
                                    <div>
                                        <br/> Comentário
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>"
                                    . $operador ." liberou as inconsistências do pedido <b>" . $numeroPedido . "</b> em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora ."</b>. 
                                </td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> Email automático enviado pelo Suprimentos. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
        return $message;
    }
    
    public function getMessageIncluirExcluirRegião($infoComentario, $txEmail) {
        $operador     = $infoComentario["NMOPERADOR"];
        $comentario   = nl2br($txEmail);
        $time         = explode(" ", $infoComentario["DTCOMENTARIO"]);
        $data         = $time[0];
        $hora         = $time[1];
        
        $message      = "<table>
                            <tr>
                                <td>"
                                    . $comentario . "</b>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>
                                    <br/> Comentário incluído em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora . " pelo operador " . $operador . "</b>. 
                                </td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> E-mail automático enviado pelo Suprimentos. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
        return $message;
    }
   
    public function deletaLogacespedcol($cdfilial, $nrpedidocol) 
    {
        try {
        
            $delete = "DELETE FROM LOGACESPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
		}
    }
   
    public function deletaComentpedcol($cdfilial, $nrpedidocol) 
    {
        try {   
            $delete = "DELETE FROM COMENTPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
		}
    }
   
    public function deletaPedcoleta($cdfilial, $nrpedcoleta, $cdforneced, $cdregiao) 
    {
        try {
            
            $delete = "DELETE FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND NRPEDCOLETA = :NRPEDCOLETA AND CDFORNECED = :CDFORNECED AND CDREGIAO = :CDREGIAO AND NRORG = :NRORG";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDCOLETA" => $nrpedcoleta,
                "CDFORNECED" => $cdforneced,
                "CDREGIAO" => $cdregiao,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function notExistsPedcoleta($cdfilial, $nrpedidocol) 
    {
        try {
            $query = "SELECT CDFILIAL, NRPEDIDOCOL FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol
            ];
    
            $std = $this->entityManager->getConnection()->prepare($query);
            $std->execute($params);
            return empty($std->fetchAll());
        } catch (\Exception $e) {
		    throw $e;
		}
    }
   
    public function deletaItempedcol($cdfilial, $nrpedcoleta, $cdforneced, $cdregiao = 'T', $cdproduto = 'T', $cdmarca = 'T') 
    {
        try {
        
            $delete = "DELETE FROM ITEMPEDCOL WHERE CDFILIAL =:CDFILIAL AND NRPEDCOLETA =:NRPEDCOLETA AND CDFORNECED =:CDFORNECED AND (CDREGIAO =:CDREGIAO OR :CDREGIAO = 'T' ) AND ( CDPRODUTO =:CDPRODUTO OR :CDPRODUTO = 'T' ) AND ( CDMARCA =:CDMARCA OR :CDMARCA = 'T' ) AND NRORG =:NRORG";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDCOLETA" => $nrpedcoleta,
                "CDFORNECED" => $cdforneced,
                "CDREGIAO" => $cdregiao,
                "CDPRODUTO" => $cdproduto,
                "CDMARCA" => $cdmarca,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
        }
    }
   
    public function deletaPrmarcpedcol($cdfilial, $nrpedidocol, $cdforneced) 
    {
        try {
        
            $delete = "DELETE FROM PRMARCPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG AND NOT EXISTS(SELECT NRPEDCOLETA FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND CDFORNECED = :CDFORNECED AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG)";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol,
                "CDFORNECED" => $cdforneced,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
        }
    }
   
    public function deletaPedcolgeral($cdfilial, $nrpedidocol) 
    {
        try {   
            $delete = "DELETE FROM PEDCOLGERAL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
        }
    }
   
    public function deletaRegiaopedcol($cdfilial, $nrpedidocol, $cdregiao) 
    {
        try {
            $delete = "DELETE FROM REGIAOPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDREGIAO = :CDREGIAO AND NRORG = :NRORG";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol,
                "CDREGIAO" => $cdregiao,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
        }
    }
   
    public function deletaFornepedcol($cdfilial, $nrpedidocol, $cdforneced) 
    {
        try {
        
            $delete = "DELETE FROM FORNEPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDFORNECED = :CDFORNECED AND NRORG = :NRORG AND NOT EXISTS(SELECT NRPEDCOLETA FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND CDFORNECED = :CDFORNECED AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG)";
    
            $params = [
                "CDFILIAL" => $cdfilial,
                "NRPEDIDOCOL" => $nrpedidocol,
                "CDFORNECED" => $cdforneced,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        } catch (\Exception $e) {
		    throw $e;
        }
    }
    
    public function verificaProcessoAceite($pedido)
    {
        try {
            if($pedido['IDUTLCTRLTERMO'] === 'N'){
                return 'N';
            } else {
                $params = [
                    "CDFILIAL" => $pedido['CDFILIAL'],
                    "NRPEDIDOCOL" => $pedido['NRPEDCOLETA'],
                    "NRORG" => $this->environment->getNrOrgTrab()
                ];
                $query = "SELECT CDFILIAL 
                            FROM ACEITEPEDCOL
                           WHERE CDFILIAL = :CDFILIAL 
                             AND NRPEDIDOCOL = :NRPEDIDOCOL 
                             AND NRORG = :NRORG
                             AND IDACEITE = 'N'";
                
                $result = $this->supUtilities->crud($query, $params);
                    
                return (isset($result) && is_array($result) && count($result)) ? 'N' : 'A';
            }
        } catch (\Exception $e) {
		    throw $e;
        }
    }
    
    public function alteraStatus($pedido, $rotina = false)
    {
        try {
            
            $idRenegociaPCol = 'S';
            if($rotina === 'liberarInconsistencia'){
                $idSituPedCol = $this->verificaProcessoAceite($pedido);
                $idRenegociaPCol = $idSituPedCol === 'A' ? 'N' : 'S';
            } else if($rotina === 'inconsistencia'){
                $idSituPedCol = 'I';
            } else{
                $idSituPedCol = 'T';
                
                $params1 = [
                    "NRPEDCOLETA" => $pedido['NRPEDCOLETA'],
                    "CDFILIAL" => $pedido['CDFILIAL'],
                    "CDFORNECED" => $pedido['CDFORNECED'],
                    "NRORG" => $this->environment->getNrOrgTrab()
                ];
                $query2 = "UPDATE ITEMPEDCOL SET IDITPEDPRIONEG = 'S' WHERE NRPEDCOLETA = :NRPEDCOLETA AND CDFILIAL = :CDFILIAL AND CDFORNECED = :CDFORNECED AND NRORG = :NRORG";
                $executaQuery = $this->entityManager->getConnection()->prepare($query2);
                $executaQuery->execute($params1);
            }
            
            $params = [
                "IDSITUPEDCOL" => $idSituPedCol,
                "IDRENEGOCIAPCOL" => $idRenegociaPCol,
                "NRPEDIDOCOL" => $pedido['NRPEDIDOCOL'],
                "CDFILIAL" => $pedido['CDFILIAL'],
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
            $query = "UPDATE PEDCOLGERAL SET IDSITUPEDCOLETA = :IDSITUPEDCOL , IDRENEGOCIAPCOL = :IDRENEGOCIAPCOL WHERE CDFILIAL =:CDFILIAL AND NRPEDIDOCOL =:NRPEDIDOCOL AND NRORG = :NRORG";
            $std = $this->entityManager->getConnection()->prepare($query);
            $std->execute($params);
            
            $query1 = "UPDATE PEDCOLETA SET IDSITUPEDCOL = :IDSITUPEDCOL WHERE :IDRENEGOCIAPCOL = :IDRENEGOCIAPCOL AND CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";
            $stmt = $this->entityManager->getConnection()->prepare($query1);
            $stmt->execute($params);
            if($idSituPedCol === 'A'){
                return true;
            }
            return false;
        } catch (\Exception $e) {
		    throw $e;
        }
    }
    
    public function pedidoColetaExists($params) 
    {
        $query = "SELECT '1' FROM ITEMCOLE I WHERE I.CDFILIAL= :P_CDFILIAL AND INSTR( :P_NRPEDIDOCOL, I.NRPEDIDOCOL ) <> 0 AND (INSTR( :P_CDREGIAO, I.CDREGIAO ) <> 0 OR :P_CDREGIAO = 'T') AND INSTR( :P_CDFORNECED, I.CDFORNECED ) <> 0";
        
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function filtroProdutosPedCol($row, $regioes){
        $filter = array(
            array(
    		    "columnName" => "P_CDREGIAO", 
    		    "value" => $regioes,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_NRPEDIDOCOL", 
    		    "value" => $row['NRPEDIDOCOL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_NRPEDCOLETA", 
    		    "value" => $row['NRPEDCOLETA'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDCOMPRADOR", 
    		    "value" => $row['COMPRADOR'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTINIVALITM", 
    		    "value" => $row['DTINIPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTFINVALITM", 
    		    "value" => $row['DTFINPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => '0',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODFIN", 
    		    "value" => 'Z',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => 'T',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTINIVALANT", 
    		    "value" => '',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTFINVALANT", 
    		    "value" => '',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_MELHORPRECO", 
    		    "value" => '1',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILIAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_IDVERIFICAVRIT", 
    		    "value" => 'N',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function filtroQtdeComprar($row, $regioes, $produtos){
        $filter = array(
            array(
    		    "columnName" => "P_CDREGIAO", 
    		    "value" => $regioes,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $produtos,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTINI", 
    		    "value" => $row['DTINIPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTFIN", 
    		    "value" => $row['DTFINPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILIAL'],
    		    "operator" => "="
		    )
    	);
    	return $filter;
    }
    
   
    
    public function atualizaQtdeAComprar($row, $regioes, $fornecedores, $pedidos){
        $sql = "UPDATE ITEMPEDCOL
                   SET QTPRODPEDCOL  = :QTACOMP
                 WHERE CDFILIAL    = :P_CDFILIAL
                   AND CDPRODUTO   = :P_CDPRODUTO
                   AND INSTR(:P_CDREGIAO, CDREGIAO) > 0
                   AND INSTR(:P_NRPEDCOLETA, NRPEDCOLETA) > 0
                   AND INSTR(:P_CDFORNECED, CDFORNECED) > 0";
            
        $params = array(
                "QTACOMP"       => $row['QTACOMPRAR'],
                "P_CDFILIAL"    => $row['CDFILIAL'],
                "P_CDPRODUTO"   => $row['CDPRODUTO'],
                "P_CDREGIAO"    => $regioes,
                "P_NRPEDCOLETA" => $pedidos,
                "P_CDFORNECED"  => $fornecedores
            );
        
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute($params);
	}
	
	public function naoConsideraMarcaProd($nrlista, $paramcompreco) {
		$sql = "SELECT
                 PRODUTO.CDARVPROD,
                 PRODUTO.NMPRODUTO,
                 PRODUTO.CDPRODUTO,
                 PRODUTO.SGUNIDADE,
                 '*****' CDMARCA,
                 '*****' NMMARCA,
                 FORNECEDOR.NMFANTFORN,
                 PRODUTO.VRFATOCONV,
                 ROUND(DECODE(:PARAMCOMPPRECO,'E',NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0) / PRODUTO.VRFATOCONV,NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0
                 ) ),3) VRPRECOOBJETIVO,
                 PRMARCPEDCOL.DSOBSRENEGOCIA,
                 PRMARCPEDCOL.NRORG
             FROM
                 PRODUTO,
                 PRMARCPEDCOL,
                 PEDCOLETA,
                 FORNECEDOR,
                 LISTA
             WHERE
                 LISTA.NRLISTA =:NRLISTA
                 AND PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                 AND PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                 AND PRMARCPEDCOL.NRPEDIDOCOL = PEDCOLETA.NRPEDIDOCOL
                 AND PRMARCPEDCOL.CDFILIAL = PEDCOLETA.CDFILIAL
                 AND PEDCOLETA.CDFORNECED = FORNECEDOR.CDFORNECED
                 AND PRMARCPEDCOL.IDMELHORPRECO = 'S'
             ORDER BY
                 PRODUTO.NMPRODUTO";
        
        $params = array(
            "NRLISTA" => $nrlista,
            "PARAMCOMPPRECO" => $paramcompreco,
        );
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	

	
	public function consideraMarcaProd($nrlista, $paramcompreco) {
    	$sql = "SELECT
                 PRODUTO.CDARVPROD,
                 PRODUTO.NMPRODUTO,
                 PRODUTO.CDPRODUTO,
                 PRODUTO.SGUNIDADE,
                 MARCA.CDMARCA,
                 MARCA.NMMARCA,
                 FORNECEDOR.NMFANTFORN,
                 PRODUTO.VRFATOCONV,
                 ROUND(DECODE(:PARAMCOMPPRECO,'E',NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0) / PRODUTO.VRFATOCONV,NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0
                 ) ),3) VRPRECOOBJETIVO,
                 PRMARCPEDCOL.DSOBSRENEGOCIA,
                 PRMARCPEDCOL.NRORG
             FROM
                 PRODUTO,
                 MARCA,
                 PRMARCPEDCOL,
                 PEDCOLETA,
                 FORNECEDOR,
                 LISTA
             WHERE
                 LISTA.NRLISTA =:NRLISTA
                 AND PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                 AND PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                 AND PRMARCPEDCOL.CDMARCA = MARCA.CDMARCA
                 AND PRMARCPEDCOL.NRPEDIDOCOL = PEDCOLETA.NRPEDIDOCOL
                 AND PRMARCPEDCOL.CDFILIAL = PEDCOLETA.CDFILIAL
                 AND PEDCOLETA.CDFORNECED = FORNECEDOR.CDFORNECED
                 AND PRMARCPEDCOL.IDMELHORPRECO = 'S'
             ORDER BY
                 PRODUTO.NMPRODUTO,
                 MARCA.NMMARCA";
        
        $params = array(
            "NRLISTA" => $nrlista,
            "PARAMCOMPPRECO" => $paramcompreco,
        );
        
    	return $this->entityManager->getConnection()->fetchAll($sql, $params);
    }
    
    public function incluirRegiao ($pedido, $regioes, $dtPedColeta, &$errorRegioes, &$regioesIncluidas) {
        foreach($regioes as $regiao) {
            try{
                $params = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"],
                    "P_CDREGIAO" => $regiao['CDREGIAO']
                );
                $sql = "INSERT INTO REGIAOPEDCOL (CDFILIAL, NRPEDIDOCOL, CDREGIAO) VALUES ( :P_CDFILIAL, :P_NRPEDIDOCOL, :P_CDREGIAO )";
                $stmt = $this->entityManager->getConnection()->prepare($sql);
                $stmt->execute($params);
            
                $params1 = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"]
                );
                $sql1 = "SELECT CDFORNECED FROM FORNEPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL";
                $stmt = $this->entityManager->getConnection()->prepare($sql1);
                $stmt->execute($params1);
                $cdForneced = $stmt->fetchAll()[0]['CDFORNECED'];
                
                $tableFilialFornecedRegiao = 'PEDCOLETA' . $pedido["CDFILIAL"] . $cdForneced . $regiao['CDREGIAO'];
                
                $stProximoCodigo = $this->newCode->getCodeByTableName($tableFilialFornecedRegiao, $this->environment->getNrOrg());
                $params2 = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDCOLETA" => $stProximoCodigo,
                    "P_CDFORNECED" => $pedido["CDFORNECED"],
                    "P_DTPEDCOLETA" => $dtPedColeta,
                    "P_CDOPERADOR" => $pedido["COMPRADOR"],
                    "P_DTINIPERCOT" => $pedido["DTINIPERGERAL"],
                    "P_DTFINPERCOT" => $pedido["DTFINPERGERAL"],
                    "P_CDREGIAO" => $regiao['CDREGIAO'],
                    "P_CDLEILAO" => null,
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"]
                );
                
                $sql2 = "INSERT INTO PEDCOLETA (CDFILIAL, NRPEDCOLETA, CDFORNECED, DTPEDCOLETA, CDOPERADOR, DTINIPERCOT, DTFINPERCOT, CDREGIAO, CDLEILAO, NRPEDIDOCOL) VALUES (:P_CDFILIAL, :P_NRPEDCOLETA, :P_CDFORNECED, :P_DTPEDCOLETA , :P_CDOPERADOR, :P_DTINIPERCOT, :P_DTFINPERCOT, :P_CDREGIAO, :P_CDLEILAO, :P_NRPEDIDOCOL)";
                $stmt = $this->entityManager->getConnection()->prepare($sql2);
                $stmt->execute($params2);
                
                $params3 = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDCOLETA" => $stProximoCodigo,
                    "P_CDFORNECED" => $pedido["CDFORNECED"],
                    "P_CDREGIAO" => $regiao['CDREGIAO'],
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"]
                );
                $sql3 = "INSERT INTO ITEMPEDCOL ( CDFILIAL, NRPEDCOLETA, CDFORNECED, CDREGIAO, CDPRODUTO, CDMARCA, VRITEMPEDCOL, VRANTITPEDCOL, VRPRECREN, VRPRECOOBJETIVO ) SELECT :P_CDFILIAL, :P_NRPEDCOLETA, :P_CDFORNECED, :P_CDREGIAO, PRMARCPEDCOL.CDPRODUTO, PRMARCPEDCOL.CDMARCA, PRMARCPEDCOL.VRPRECUNIPRMARC, PRMARCPEDCOL.VRULTPRECPRMARC, PRMARCPEDCOL.VRPRECREN, PRMARCPEDCOL.VRPRECOOBJETIVO FROM PRMARCPEDCOL WHERE PRMARCPEDCOL.CDFILIAL =:P_CDFILIAL AND PRMARCPEDCOL.NRPEDIDOCOL =:P_NRPEDIDOCOL";
                $stmt = $this->entityManager->getConnection()->prepare($sql3);
                $stmt->execute($params3);
                array_push($regioesIncluidas, array("CDREGIAO" => $regiao["CDREGIAO"], "NMREGIAO" => $regiao["NMREGIAO"]));
            } catch(\Exception $e){
                if(strpos($e->getMessage(), 'ORA-00001')){
                    array_push($errorRegioes, array( "NRPEDIDOCOL" => "Pedido: " . $pedido['NRPEDIDOCOL'], "REGIAO" => "Região: " . $regiao["CDREGIAO"] . " - " . $regiao["NMREGIAO"]));
                }
            }
         }
    }
    
    public function excluirRegiao ($pedido, $regioes, &$errorRegioes, &$regioesExcluidas) {
        foreach($regioes as $regiao) {
            $params = array(
                "P_CDFILIAL" => $pedido["CDFILIAL"],
                "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"],
                "P_CDREGIAO" => $regiao['CDREGIAO']
            );
            
            
            $sql = "SELECT * FROM REGIAOPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDREGIAO = :P_CDREGIAO";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
            $regionExists = $stmt->fetchAll();
            
            if (((is_array($regionExists) && !is_null($regionExists)) ? count($regionExists) : 0) > 0) {
                $sql1 = "DELETE FROM REGIAOPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDREGIAO = :P_CDREGIAO";
                $stmt = $this->entityManager->getConnection()->prepare($sql1);
                $stmt->execute($params);
                
                $sql2 = "DELETE FROM ITEMPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND CDREGIAO = :P_CDREGIAO AND EXISTS (SELECT 1 FROM PEDCOLETA WHERE PEDCOLETA.CDFILIAL = :P_CDFILIAL AND PEDCOLETA.NRPEDIDOCOL = :P_NRPEDIDOCOL AND PEDCOLETA.CDREGIAO =:P_CDREGIAO AND PEDCOLETA.CDFILIAL = ITEMPEDCOL.CDFILIAL AND PEDCOLETA.CDFORNECED = ITEMPEDCOL.CDFORNECED AND PEDCOLETA.NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA AND PEDCOLETA.CDREGIAO = ITEMPEDCOL.CDREGIAO)";
                $stmt = $this->entityManager->getConnection()->prepare($sql2);
                $stmt->execute($params);
            
                $sql3 = "DELETE FROM PEDCOLETA WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDREGIAO = :P_CDREGIAO";
                $stmt = $this->entityManager->getConnection()->prepare($sql3);
                $stmt->execute($params);
                array_push($regioesExcluidas, array("CDREGIAO" => $regiao["CDREGIAO"], "NMREGIAO" => $regiao["NMREGIAO"]));
            }else{
                array_push($errorRegioes, array( "NRPEDIDOCOL" => "Pedido: " . $pedido['NRPEDIDOCOL'], "REGIAO" => "Região: " . $regiao["CDREGIAO"] . " - " . $regiao["NMREGIAO"]));
            }
         }
    }
    
    public function ACEITA_PEDCOTWEB($cdfilial, $nrpedidocol, $idconsiste) 
    {
         try {
            $connection = $this->entityManager->getConnection();
            
            $procedure = new StoredProcedure($connection, 'ACEITA_PEDCOTWEB');
            $procedure->addParam(new Param('P_CDFILIAL',    Param::PARAM_INPUT,  $cdfilial,    Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDIDOCOL', Param::PARAM_INPUT,  $nrpedidocol, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDCONSISTE',  Param::PARAM_INPUT,  $idconsiste,  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDACEITEOK',  Param::PARAM_OUTPUT, null,         Param::PARAM_TYPE_STR, 200));
        
            return $procedure->execute();
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    public function excluirProdutos($produto, $nrPedColeta) {
        
        $this->deletaItempedcol($produto['CDFILIAL'], $nrPedColeta, $produto['CDFORNECED'], 'T', $produto['CDPRODUTO']);
        
        $params = [
            "CDFILIAL" => $produto['CDFILIAL'],
            "NRPEDIDOCOL" => $produto['NRPEDIDOCOL'],
            "CDPRODUTO" => $produto['CDPRODUTO'],
            "NRORG" => $produto['NRORG']
        ];
        $sql = "DELETE FROM PRMARCPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDPRODUTO = :CDPRODUTO AND NRORG =:NRORG";

        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
    }
    
    public function getIdSisDos() {
        $query = "SELECT IDSISDOS FROM PARAMGERAL";
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute();
        return $std->fetchAll()[0]['IDSISDOS'];
    }
    
    public function verifyRegionsFromOrder($row) 
    {
        $query =   "SELECT
                        COUNT(CDREGIAO) AS NUMREGIOES
                    FROM
                        REGIAOPEDCOL
                    WHERE 
                        NRPEDIDOCOL = :P_NRPEDIDOCOL";
                        
        $params = [
            "P_NRPEDIDOCOL" => $row["NRPEDIDOCOL"]
        ];  
        
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        $result = $std->fetchAll();
        
        return $result[0];
    }
    
    public function insertMarcPedCol($row) 
    {
        try {
            $sql = "INSERT INTO 
                        PRMARCPEDCOL
                        ( 
                            CDFILIAL, 
                            NRPEDIDOCOL, 
                            CDPRODUTO, 
                            CDMARCA, 
                            VRPRECUNIPRMARC, 
                            QTDISPPRODMARC, 
                            VRULTPRECPRMARC, 
                            IDITPEDPRIONEG,
                            DSOBSRENEGOCIA,
                            IDPRODINCLFOR
                        )
                    VALUES
                        (
                            :P_CDFILIAL,
                            :P_NRPEDIDOCOL,
                            :P_CDPRODUTO,
                            :P_CDMARCA,
                            :P_VRPRECUNIPRMARC,
                            :P_QTDISPPRODMARC,
                            :P_VRULTPRECPRMARC,
                            :P_IDITPEDPRIONEG,
                            :P_DSOBSRENEGOCIA,
                            :P_IDPRODINCLFOR
                        )";
            
            $params = array(
                "P_CDFILIAL" => $row[0]['CDFILIAL'],
                "P_NRPEDIDOCOL" => $row[0]['NRPEDIDOCOL'],
                "P_CDPRODUTO" => $row[0]['CDPRODUTO'],
                "P_CDMARCA" => $row[0]['CDMARCA'],
                "P_VRPRECUNIPRMARC" => $row[0]['VRPRECUNIPRMARC'],
                "P_QTDISPPRODMARC" => $row[0]['QTDISPPRODMARC'],
                "P_VRULTPRECPRMARC" => $row[0]['VRULTPRECPRMARC'],
                "P_IDITPEDPRIONEG" => $row[0]['IDITPEDPRIONEG'],
                "P_DSOBSRENEGOCIA" => $row[0]['DSOBSRENEGOCIA'],
                "P_IDPRODINCLFOR" => $row[0]['IDPRODINCLFOR']
            );
            
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    public function insertItemPedCol($row) {
        try {
            $sql = "INSERT INTO 
                        ITEMPEDCOL
                        ( 
                            CDFILIAL, 
                            NRPEDCOLETA, 
                            CDFORNECED, 
                            CDREGIAO, 
                            CDPRODUTO, 
                            CDMARCA, 
                            VRITEMPEDCOL, 
                            VRANTITPEDCOL
                        )
                    SELECT
                       PEDCOLETA.CDFILIAL,
                       PEDCOLETA.NRPEDCOLETA,
                       PEDCOLETA.CDFORNECED,
                       PEDCOLETA.CDREGIAO,
                       PRMARCPEDCOL.CDPRODUTO,
                       PRMARCPEDCOL.CDMARCA,
                       PRMARCPEDCOL.VRPRECUNIPRMARC,
                       PRMARCPEDCOL.VRULTPRECPRMARC
                    FROM 
                        PRMARCPEDCOL, 
                        PEDCOLETA
                    WHERE 
                        PRMARCPEDCOL.CDFILIAL         = :P_CDFILIAL
                        AND PRMARCPEDCOL.NRPEDIDOCOL  = :P_NRPEDCOLETA
                        AND PRMARCPEDCOL.CDPRODUTO    = :P_CDPRODUTO
                        AND PRMARCPEDCOL.CDMARCA      = :P_CDMARCA
                        AND PEDCOLETA.CDFILIAL        = PRMARCPEDCOL.CDFILIAL
                        AND PEDCOLETA.NRPEDIDOCOL     = PRMARCPEDCOL.NRPEDIDOCOL";
                      
            $params = array(
                "P_CDFILIAL" => $row[0]['CDFILIAL'],
                "P_NRPEDCOLETA" => $row[0]['NRPEDIDOCOL'],
                "P_CDPRODUTO" => $row[0]['CDPRODUTO'],
                "P_CDMARCA" => $row[0]['CDMARCA']
            );
            
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
        } catch (\Exception $e){
            throw $e;
        }
    }
    
    public function insertComentPedCol($row) 
    {
        try {
            $this->entityManager->beginTransaction();

            $sql = "INSERT INTO 
                        COMENTPEDCOL 
                        (
                            CDFILIAL, 
                            NRPEDIDOCOL, 
                            DTCOMENTARIO, 
                            CDOPERADOR, 
                            TXCOMENTARIO, 
                            DTINCLUSAO, 
                            DTULTATU, 
                            NRORG, 
                            DSDOCUMENTOANEXO, 
                            DSIDDOCFILESERV 
                        ) 
                    VALUES 
                        ( 
                            :P_CDFILIAL, 
                            :P_NRPEDIDOCOL, 
                            SYSDATE, 
                            :P_CDOPERADOR, 
                            :P_TXCOMENTARIO, 
                            SYSDATE, 
                            SYSDATE, 
                            :NRORG, 
                            :DSDOCUMENTOANEXO, 
                            :DSIDDOCFILESERV
                        )";
                        
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute(
                array(
                    "P_CDFILIAL"     => $row['CDFILIAL'],
                    "P_NRPEDIDOCOL"  => $row['NRPEDIDOCOL'],
                    "P_CDOPERADOR"   => $row['CDOPERADOR'],
                    "P_TXCOMENTARIO" => $row['TXCOMENTARIO'],
                    "NRORG"          => $row['NRORG'],
                    "DSDOCUMENTOANEXO" => '',
                    "DSIDDOCFILESERV" => ''
                )
            );
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e){
            $this->entityManager->rollBack();
            throw $e;
        }
        
        $sql = "SELECT 
                    C.CDFILIAL, 
                    C.NRPEDIDOCOL, 
                    C.CDOPERADOR, 
                    O.NMOPERADOR, 
                    C.DTCOMENTARIO, 
                    C.TXCOMENTARIO 
                FROM 
                (
                    SELECT 
                        * 
                    FROM 
                        COMENTPEDCOL 
                    WHERE 
                        CDFILIAL = :P_CDFILIAL 
                        AND NRPEDIDOCOL = :P_NRPEDIDOCOL 
                        AND CDOPERADOR = :P_CDOPERADOR 
                    ORDER BY 
                        DTCOMENTARIO DESC
                ) C, 
                OPERADOR O 
                WHERE 
                    C.CDOPERADOR = O.CDOPERADOR 
                    AND ROWNUM = 1";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $row['CDFILIAL'],
                "P_NRPEDIDOCOL"  => $row['NRPEDIDOCOL'],
                "P_CDOPERADOR"   => $row['CDOPERADOR'],
            )
        );
        
        return($stmt->fetchAll()[0]);
    }
    
    public function enviaEmailComentario($infoComentario, $row, $response)
    {
        try{
            $operador = $row['NMOPERADOR'];
            $comentario = nl2br($infoComentario["TXCOMENTARIO"]);
            $numeroPedido = $infoComentario["NRPEDIDOCOL"];
            $time = explode(" ", $infoComentario["DTCOMENTARIO"]);
            $data = $time[0];
            $hora = $time[1];
            
            $message = $this->getMessageHTML($operador, $comentario, $numeroPedido, $data, $hora);
            $assunto = 'Comentário - '.$infoComentario["NRPEDIDOCOL"];
            $messageSendMail = $this->supUtilities->messageSendMail($row['CDFILIAL'], $assunto, $message,'PORTAL E-COMMERCE');
            $emailDestino = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);
            
            $this->supUtilities->enviaEmail('', $assunto, '', $messageSendMail, $emailDestino);
        }catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error ($e->getMessage(),500));
        }
    }
    
    public function getMessageHTML($operador, $comentario, $numeroPedido, $data, $hora) 
    {
        return "<table>
            <tr>
                <td>"
                    . $operador ." incluiu um novo comentário no pedido <b>" . $numeroPedido . "</b> em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora ."</b>. 
                </td>
            </tr>
            <tr>
                <td class='title'> 
                    <div>
                        <br/> Comentário
                    </div>
                </td>
            </tr>
            <tr>
                <td class='description'>
                    <br/>" . $comentario .
                "</td>
            </tr>
            <tr class='footer'>
                <td>
                    <center>
                        <br> <p> Email automático enviado pelo Portal E-commerce. </p> 
                    </center>
                </td>
            </tr>
        </table>";
    }
    
    public function atualizaDataValidadePedcolgeral($nrpedido, $cdfilial, $dtInicial, $dtFinal) {
        try {
            $sql = "UPDATE PEDCOLGERAL
                       SET DTINIPERGERAL = :DTINIPERGERAL,
                           DTFINPERGERAL = :DTFINPERGERAL 
                     WHERE (INSTR(:NRPEDGRID, NRPEDIDOCOL) <> 0)
                       AND (INSTR(:CDFILIAL, CDFILIAL) <> 0)";
    
            $params = array(
                "DTINIPERGERAL" => $dtInicial,
                "DTFINPERGERAL" => $dtFinal,
                "NRPEDGRID" => $nrpedido,
                "CDFILIAL" => $cdfilial
            );
            
            $std = $this->entityManager->getConnection()->prepare($sql);
            
            $std->execute($params);
        } catch(\Exception $e) {
            throw new \Exception("Erro ao atualizar a validade");
        }
    }
    
    public function atualizaDataValidadePedcoleta($nrpedido, $dtInicial, $dtFinal) 
    {
        try {
            $sql = "UPDATE PEDCOLETA
                       SET DTINIPERCOT = :DTINIPERCOT, 
                           DTFINPERCOT = :DTFINPERCOT
                    WHERE (INSTR(:NRPEDGRID, NRPEDIDOCOL) <> 0)";
    
            $params = array(
                "DTINIPERCOT" => $dtInicial,
                "DTFINPERCOT" => $dtFinal,
                "NRPEDGRID" => $nrpedido,
            );
    
            $std = $this->entityManager->getConnection()->prepare($sql);
            
            $std->execute($params);
        } catch(\Exception $e) {
            throw new \Exception("Erro ao atualizar a validade");
        }
    }
    
    public function existeListaPreco($pedido) 
    {
        try {
        
            $sql = "SELECT NRSEQPRELIST, CDFILIAL
                      FROM PREVLISTA
                     WHERE CDOPERADOR = :P_CDCOMPRADOR
                       AND DTINIVALLIST <= :P_DTFIN
                       AND DTFINVALLIST >= :P_DTINI
                       AND (IDSTATUSPRLIST = 'D' OR IDSTATUSANTLIST = 'D')";
                       
            $params = [
                "P_CDCOMPRADOR" => $pedido['CDOPERADOR'],
                "P_DTFIN" => $pedido['DTINIPERCOT'],
                "P_DTINI" => $pedido['DTFINPERCOT']
            ];
            
            return $this->entityManager->getConnection()->fetchAll($sql, $params);
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function verificaListaPrecoDefinitiva($lista, $pedido)
    {
        try {
            
            $resultMsg = '';
        
            $sql = "SELECT ITEMCOLE.CDFILIAL
                      FROM ITEMCOLE INNER JOIN COLETAPR ON ITEMCOLE.CDFILIAL    = COLETAPR.CDFILIAL
                                                       AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO
                     WHERE ITEMCOLE.CDFILIAL      = :P_CDFILIAL
                       AND ITEMCOLE.NRSEQPRELIST  = :P_NRSEQPRELIST
                       AND COLETAPR.CDOPERADOR    = :P_CDCOMPRADOR
                       AND ITEMCOLE.IDITVALDIFLISTA <>  'S'
                       AND ITEMCOLE.DTINIVALITM  <= :P_DTFIN
                       AND ITEMCOLE.DTFINVALITM  >= :P_DTINI
                       AND ITEMCOLE.IDITMLISPREC  = 'S'";
                        
            $params = [
                "P_CDFILIAL"     => $lista['CDFILIAL'],
                "P_NRSEQPRELIST" => $lista['NRSEQPRELIST'],
                "P_CDCOMPRADOR"  => $pedido['CDOPERADOR'],
                "P_DTFIN"        => $pedido['DTFINPERCOT'],
                "P_DTINI"        => $pedido['DTINIPERCOT']
            ];
            
            $result = $this->supUtilities->crud($sql, $params);
            
            if(isset($result) && is_array($result) && !count($result)) {
                $resultMsg = 'LISTAPREC_DEFINITIVA';
            } else {
                $sql = "SELECT ITEMCOLE.CDFILIAL
                          FROM ITEMCOLE INNER JOIN COLETAPR ON ITEMCOLE.CDFILIAL    = COLETAPR.CDFILIAL
                                                           AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO
                         WHERE ITEMCOLE.CDFILIAL      = :P_CDFILIAL
                           AND COLETAPR.CDOPERADOR    = :P_CDCOMPRADOR
                           AND ITEMCOLE.IDITVALDIFLISTA = 'S'
                           AND ITEMCOLE.DTINIVALITM  <= :P_DTFIN
                           AND ITEMCOLE.DTFINVALITM  >= :P_DTINI
                           AND ITEMCOLE.IDITMLISPREC  = 'S'";
                        
                $params = [
                    "P_CDFILIAL" => $cdfilial,
                    "P_CDCOMPRADOR" => $cdcomprador,
                    "P_DTFIN" => $dtFinal,
                    "P_DTINI" => $dtInicial
                ];
                
                $result = $this->supUtilities->crud($sql, $params);
                
                if(isset($result) && is_array($result) && count($result)) {
                    $resultMsg = 'LISTAPREC_DEFINITIVA';
                }   
                
            }
            
            return $resultMsg;
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function adqExisteCotacao1 ($cdfilial, $cdcomprador,$dtFinal,$dtInicial) {
        
        $sql = "SELECT COUNT(1) CONTADOR
                  FROM ITEMCOLE, COLETAPR
                 WHERE ITEMCOLE.CDFILIAL      = :P_CDFILIAL
                   AND ITEMCOLE.CDFILIAL      = COLETAPR.CDFILIAL
                   AND ITEMCOLE.NRCOLEPRECO   = COLETAPR.NRCOLEPRECO
                   AND COLETAPR.CDOPERADOR    = :P_CDCOMPRADOR
                   AND ITEMCOLE.IDITVALDIFLISTA = 'S'
                   AND ITEMCOLE.DTINIVALITM  <= :P_DTFIN
                   AND ITEMCOLE.DTFINVALITM  >= :P_DTINI
                   AND ITEMCOLE.IDITMLISPREC  = 'S'";
                    
        $params = [
            "P_CDFILIAL" => $cdfilial,
            "P_CDCOMPRADOR" => $cdcomprador,
            "P_DTFIN" => $dtFinal,
            "P_DTINI" => $dtInicial
            
        ];
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
        
    }
    

    public function selectQtdeAComprarMediaAF($row, $regioes, $produtos, $QTMESES, $marca) {
		$sql = "SELECT ROUND(SUM(NVL(AF.QTDEACOMPRAR, 0)), 2) QTDEACOMPRAR
                    FROM (SELECT ROUND((SUM(ITEMAUTF.QTEFETENTRAF * PRODUTO.VRFATOCONV) / :P_QTMESES), 2) QTDEACOMPRAR
                            FROM ITEMAUTF INNER JOIN AUTOFORNE           ON AUTOFORNE.CDFILDEST     = ITEMAUTF.CDFILDEST
                                                                        AND AUTOFORNE.CDFILLANC     = ITEMAUTF.CDFILLANC
                                                                        AND AUTOFORNE.NRAUTOFORN    = ITEMAUTF.NRAUTOFORN
                                          INNER JOIN RELACPRODOL         ON ITEMAUTF.CDPRODUTO      = RELACPRODOL.CDPRODARVOL
                                          INNER JOIN PRODUTO             ON RELACPRODOL.CDPRARVORIG = PRODUTO.CDPRODUTO
                                                                        AND RELACPRODOL.CDMARCA     = :V_CDMARCA
                                          INNER JOIN FILIAL              ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                           WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                             AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                             AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                             AND AUTOFORNE.IDAFFORALIM = 'N'
                             AND FILIAL.CDREGIAO       = :V_CDREGIAO
                             AND PRODUTO.CDPRODUTO     = :V_CDPRODUTO
                             AND ITEMAUTF.DTPROGENTAF BETWEEN ADD_MONTHS(SYSDATE, -(:P_QTMESES)) AND (SYSDATE - 1)
                             AND AUTOFORNE.CDFORNECED  = NVL(:V_CDFORNECED, AUTOFORNE.CDFORNECED)
                             AND ITEMAUTF.NRORG = :P_NRORG
                             AND AUTOFORNE.NRORG = :P_NRORG
                             AND RELACPRODOL.NRORG = :P_NRORG
                             AND PRODUTO.NRORG = :P_NRORG
                             AND FILIAL.NRORG = :P_NRORG
                          UNION
                          SELECT ROUND((SUM((ITEMAUTF.QTEFETENTRAF * PRODESTO.VRFATOCONV)/PRODUTO.VRFATOCONV) / :P_QTMESES), 2) QTDEACOMPRAR
                            FROM ITEMAUTF INNER JOIN AUTOFORNE        ON AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
                                                                     AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
                                                                     AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                          INNER JOIN PRODUTO PRODESTO ON ITEMAUTF.CDPRODUTO   = PRODESTO.CDPRODUTO
                                          INNER JOIN PRODUTO          ON ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
                                          INNER JOIN FILIAL           ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                           WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                             AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                             AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                             AND AUTOFORNE.IDAFFORALIM = 'N'
                             AND FILIAL.CDREGIAO       = :V_CDREGIAO
                             AND PRODESTO.CDPRODESTO   = PRODUTO.CDPRODESTO
                             AND PRODUTO.CDPRODUTO     = :V_CDPRODUTO
                             AND ITEMAUTF.DTPROGENTAF BETWEEN ADD_MONTHS(SYSDATE, -(:P_QTMESES)) AND (SYSDATE - 1)
                             AND AUTOFORNE.CDFORNECED  = NVL(:V_CDFORNECED, AUTOFORNE.CDFORNECED)
                             AND ITEMAUTF.NRORG  = :P_NRORG
                             AND AUTOFORNE.NRORG = :P_NRORG
                             AND PRODESTO.NRORG  = :P_NRORG
                             AND PRODUTO.NRORG   = :P_NRORG
                             AND FILIAL.NRORG    = :P_NRORG) AF";
        
        $params = array(
            "V_CDMARCA" => $marca,
            "P_NRORG" => $row['NRORG'],
            "V_CDFORNECED" =>$row['CDFORNECED'],
            "V_CDPRODUTO" => $produtos,
            "P_QTMESES" => $QTMESES,
            "V_CDREGIAO" => $regioes
        );

        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	
	public function selectQtdeAComprarMediaAF2($row, $regioes, $produtos, $QTMESES, $marca) {
		$sql = "   SELECT ROUND(SUM(NVL(AF.QTDEACOMPRAR, 0)), 2) QTDEACOMPRAR
                    FROM (SELECT ROUND((SUM(ITEMAUTF.QTEFETENTRAF * PRODUTO.VRFATOCONV) / :P_QTMESES), 2) QTDEACOMPRAR
                            FROM ITEMAUTF INNER JOIN AUTOFORNE           ON AUTOFORNE.CDFILDEST     = ITEMAUTF.CDFILDEST
                                                                        AND AUTOFORNE.CDFILLANC     = ITEMAUTF.CDFILLANC
                                                                        AND AUTOFORNE.NRAUTOFORN    = ITEMAUTF.NRAUTOFORN
                                          INNER JOIN RELACPRODOL         ON ITEMAUTF.CDPRODUTO      = RELACPRODOL.CDPRODARVOL
                                          INNER JOIN PRODUTO             ON RELACPRODOL.CDPRARVORIG = PRODUTO.CDPRODUTO
                                                                        AND RELACPRODOL.CDMARCA     = :V_CDMARCA
                                          INNER JOIN FILIAL              ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                           WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                             AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                             AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                             AND AUTOFORNE.IDAFFORALIM = 'N'
                             AND FILIAL.CDREGIAO       = :V_CDREGIAO
                             AND PRODUTO.CDPRODUTO     = :V_CDPRODUTO
                             AND ITEMAUTF.DTPROGENTAF BETWEEN ADD_MONTHS(SYSDATE, -(:P_QTMESES)) AND (SYSDATE - 1)
                             AND AUTOFORNE.CDFORNECED  = NVL('', AUTOFORNE.CDFORNECED)
                             AND ITEMAUTF.NRORG = :P_NRORG
                             AND AUTOFORNE.NRORG = :P_NRORG
                             AND RELACPRODOL.NRORG = :P_NRORG
                             AND PRODUTO.NRORG = :P_NRORG
                             AND FILIAL.NRORG = :P_NRORG
                          UNION
                          SELECT ROUND((SUM((ITEMAUTF.QTEFETENTRAF * PRODESTO.VRFATOCONV)/PRODUTO.VRFATOCONV) / :P_QTMESES), 2) QTDEACOMPRAR
                            FROM ITEMAUTF INNER JOIN AUTOFORNE        ON AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
                                                                     AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
                                                                     AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                          INNER JOIN PRODUTO PRODESTO ON ITEMAUTF.CDPRODUTO   = PRODESTO.CDPRODUTO
                                          INNER JOIN PRODUTO          ON ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
                                          INNER JOIN FILIAL           ON AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
                           WHERE AUTOFORNE.IDSITUATUAAF IS NULL
                             AND NVL(AUTOFORNE.IDBAIXAAF,'0') <> '6'
                             AND ITEMAUTF.IDBAIXITMAF IN ('1', '2')
                             AND AUTOFORNE.IDAFFORALIM = 'N'
                             AND FILIAL.CDREGIAO       = :V_CDREGIAO
                             AND PRODESTO.CDPRODESTO   = PRODUTO.CDPRODESTO
                             AND PRODUTO.CDPRODUTO     = :V_CDPRODUTO
                             AND ITEMAUTF.DTPROGENTAF BETWEEN ADD_MONTHS(SYSDATE, -(:P_QTMESES)) AND (SYSDATE - 1)
                             AND AUTOFORNE.CDFORNECED  = NVL('', AUTOFORNE.CDFORNECED)
                             AND ITEMAUTF.NRORG = :P_NRORG
                             AND AUTOFORNE.NRORG = :P_NRORG
                             AND PRODESTO.NRORG = :P_NRORG
                             AND PRODUTO.NRORG = :P_NRORG
                             AND FILIAL.NRORG = :P_NRORG) AF";
        
        $params = array(
            "V_CDMARCA" => $marca,
            "P_NRORG" => $row['NRORG'],
            "V_CDFORNECED" =>$row['CDFORNECED'],
            "V_CDPRODUTO" => $produtos,
            "P_QTMESES" => $QTMESES,
            "V_CDREGIAO" => $regioes
        );
        
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
    public function atualizaQtdeAComprarMediaAF($row, $regiao, $fornecedor, $pedido){
        $sql = "UPDATE ITEMPEDCOL
                   SET QTPRODPEDCOL  = :QTACOMP
                 WHERE CDFILIAL    = :P_CDFILIAL
                   AND CDPRODUTO   = :P_CDPRODUTO
                   AND CDREGIAO = :P_CDREGIAO
                   AND NRPEDCOLETA = :P_NRPEDCOLETA
                   AND CDFORNECED = :P_CDFORNECED";
            
        $params = array(
                "QTACOMP"       => $row['QTACOMPRAR'],
                "P_CDFILIAL"    => $row['CDFILIAL'],
                "P_CDPRODUTO"   => $row['CDPRODUTO'],
                "P_CDREGIAO"    => $regiao,
                "P_NRPEDCOLETA" => $pedido,
                "P_CDFORNECED"  => $fornecedor
            );
        
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute($params);
	}

    public function selectlista ($row) {
        
        $sql = "SELECT DISTINCT
                nvl(p.nrpedidocol, p.nrpedcoleta) AS nrpedido,
                i.NRCOLEPRECO,
                NVL(i.nrseqprelist, 'SEM LISTA GERADA') AS  listapreco,
                l.nrseqprelist,
                
                l.dsprevlist
            FROM
                pedcoleta   p
                INNER JOIN itemcole    i ON i.cdfilial = p.cdfilial
                                         AND i.cdregiao = p.cdregiao
                                         AND i.cdforneced = p.cdforneced
                                         AND i.nrpedidocol = p.nrpedidocol
                LEFT JOIN prevlista   l ON l.cdfilial = i.cdfilial
                                         AND l.nrseqprelist = i.nrseqprelist
            WHERE
                p.cdfilial = :CDFILIAL
                AND p.cdregiao = :CDREGIAO
                AND p.CDFORNECED = :CDFORNECED
                AND P.NRPEDIDOCOL = :NRPEDIDOCOL";
                    
        $params = [
            "CDFILIAL"      => $row['CDFILIAL'],
            "CDREGIAO"      => $row['CDREGIAO'],
            "CDFORNECED"    => $row['CDFORNECED'],
            "NRPEDIDOCOL"   => $row['NRPEDIDOCOL']
        ];
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
        
    }
    
    /*********************************************/
    
    private function generateCode($table)
    {
        return $this->newCode->getCodeByTableName($table, $this->environment->getNrOrg());
    }
    
    public function insertSupplierList($arraySupplier)
    {
        $nrList = self::generateCode('LISTA');
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) 
                    (SELECT :NRLISTA, CDFORNECED, NRORG
                       FROM FORNECEDOR)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    'NRLISTA' => $nrList
                )
            );
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function selectMsgEnvEmail($funcionalidade) 
    {
        try {
            $query = "SELECT DSSUBJECT,DSBODY 
                        FROM MENSAGEMPADRAOEMAIL 
                       WHERE IDOPERACAO = :P_IDOPERACAO";
    
            $params = [
                "P_IDOPERACAO" => $funcionalidade
            ];
    
            $result = $this->supUtilities->crud($query, $params);
            return isset($result[0]) ? $result[0] : [];
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    private function getCentralCompras() 
    {
        try {
            $query = "SELECT NVL(CDFILCENTCMP, CDFILIAL) CDFILIAL
                        FROM FILIAL 
                       WHERE CDFILIAL = :CDFILIAL";
            $params = [
                "CDFILIAL"=> $this->environment->getCdFilial()
            ];
            $result =  $this->supUtilities->crud($query, $params);
            return $result[0]['CDFILIAL'];
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getURLPortal()
    {
        try {
            $query = "SELECT DSLINKECOMMERCE 
                        FROM PARAMGERALECOMMERCE 
                       WHERE CDFILIAL = :P_CDFILIAL";
            $params = [
                "P_CDFILIAL"=> $this->getCentralCompras()
            ];
            $result =  $this->supUtilities->crud($query, $params);
            return isset($result[0]['DSLINKECOMMERCE']) ? $result[0]['DSLINKECOMMERCE'] : '';
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
}